{% load i18n %}

<div class="detail">
    <dl class="dl-horizontal">
        <dt>{% trans "Name" %}</dt>
        <dd>{{ application.name }}</dd>
        <dt>{% trans "ID" %}</dt>
        <dd>{{ application.id }}</dd>
        <dt>{% trans "Created at" %}</dt>
        <dd>{{ application.created_at|parse_isotime }}</dd>
        <dt>{% trans "Updated at" %}</dt>
        <dd>{{ application.updated_at|parse_isotime }}</dd>
        <dt>{% trans "Description" %}</dt>
        <dd>{{ application.description|default:"None" }}</dd>
        <dt>{% trans "Languagepack" %}</dt>
        <dd>{{ application.languagepack }}</dd>
        <dt>{% trans "Entry points" %}</dt>
        <dd>{{ application.entry_points }}</dd>
        <dt>{% trans "Ports" %}</dt>
        <dd>{{ application.ports }}</dd>
        <dt>{% trans "Source" %}</dt>
        <dd>{{ application.source }}</dd>
        <dt>{% trans "Trigger UUID" %}</dt>
        <dd>{{ application.trigger_uuid }}</dd>
        <dt>{% trans "Trigger" %}</dt>
        <dd>{{ application.trigger }}</dd>
        <dt>{% trans "App URL" %}</dt>
        <dd>{{ application.app_url }}</dd>

        {% if application.target_instances %}
            <dt>{% trans "Target Instances" %}</dt>
            <dd>{{ application.target_instances }}</dd>
        {% endif %}

    </dl>

    <h4>{% trans "Workflow details for" %}: {{ application.name }}</h4>

        <hr class="header_rule">
        <dl class="dl-horizontal">
        {% for workflow in workflows %}
            <dt>{% trans "Workflow ID" %}</dt>
            <dd>{{ workflow.wf_id }}</dd>
            <dt>{% trans "ID" %}</dt>
            <dd>{{ workflow.id }}</dd>
            <dt>{% trans "Status" %}</dt>
            <dd>{{ workflow.status }}</dd>
            {% empty %}
            <dd><em>{% trans "No Workflow details." %}</em></dd>
        {% endfor %}
    </dl>
</div>
